(*
 * The LOOP Project
 *
 * The LOOP Team, Dresden University and Nijmegen University
 *
 * Copyright (C) 2002
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License in file COPYING in this or one of the
 * parent directories for more details.
 *
 * Created 2.5.02 by Hendrik
 *
 * Time-stamp: <Thursday 21 August 03 17:05:28 tews@ithif51.inf.tu-dresden.de>
 *
 * part of global.ml that is configurable
 *
 * $Id: config.ml,v 1.5 2003/08/21 15:14:59 tews Exp $
 *
 *)


(* 
 * Set this variable to the default location of the fixedpoint library.
 * Should be the same as LIBDIR in ../Makefile.
 *)

(* USE prelude gfp now
 * 
 * let fixedpointlib = "/sun/theorie/tews/Privat/Coda/Work2/Lib/Pvs"
 * 
 *)

(*** Local Variables: ***)
(*** version-control: t ***)
(*** kept-new-versions: 5 ***)
(*** delete-old-versions: t ***)
(*** time-stamp-line-limit: 30 ***)
(*** End: ***)
